@@ -7,7 +7,7 @@ use Carp;
 use Dancer2::Plugin;
 use Class::Load qw(try_load_class);
 
-our $VERSION = '0.304';
+our $VERSION = '0.305';
 
 my $settings;
 
@@ -42,7 +42,8 @@ methods/sources (config file, database, Unix system users, etc).
 Designed to support multiple authentication realms and to be as extensible as
 possible, and to make secure password handling easy.  The base class for auth
 providers makes handling C<RFC2307>-style hashed passwords really simple, so you
-have no excuse for storing plain-text passwords.  A simple script to generate
+have no excuse for storing plain-text passwords.  A simple script called
+B<generate-crypted-password> to generate
 RFC2307-style hashed passwords is included, or you can use L<Crypt::SaltedHash>
 yourself to do so, or use the C<slappasswd> utility if you have it installed.
 
@@ -515,7 +516,7 @@ In your application's configuation file:
 B<Please note> that you B<must> have a session provider configured.  The 
 authentication framework requires sessions in order to track information about 
 the currently logged in user.
-Please see L<Dancer2::Session> for information on how to configure session 
+Please see L<Dancer2::Core::Session> for information on how to configure session 
 management within your application.
 
 =cut
@@ -615,8 +616,24 @@ on_plugin_import {
                     $settings->{login_page_handler} || '_default_login_page';
                 no strict 'refs';
                 return &{$_default_login_page}($dsl);
-            });
+            }
+        );
 
+        $app->add_route(
+            method => 'get',
+            regexp => $deniedpage,
+            code => sub {
+                $dsl->response->status(403);
+                my $_default_permission_denied_page =
+                    $settings->{permission_denied_page_handler}
+                    || '_default_permission_denied_page';
+                no strict 'refs';
+                return &{$_default_permission_denied_page}($dsl);
+            }
+        );
+    }
+
+    if ( !$settings->{no_login_handler} ) {
         $app->add_route(
             method => 'post',
             regexp => $loginpage,
@@ -778,11 +795,13 @@ Support for user_roles looking in other realms by Colin Ewen (casao)
 
 LDAP provider added by Mark Meyer (ofosos)
 
-Config options for default login/logout handlers by Henk van Oers (hvoers)
-
 Documentation fix by Vince Willems.
 
-Support for DBIC provider and warning on missing realms by Andrew Beverley.
+Henk van Oers (GH #8, #13).
+
+Andrew Beverly (GH #6, #7, #17).
+
+Gabor Szabo (GH #11, #16).
 
 =head1 LICENSE AND COPYRIGHT
 
