@@ -3,7 +3,7 @@ package Dancer2::Plugin::Auth::Extensible::Provider::Base;
 use strict;
 use Crypt::SaltedHash;
 
-our $VERSION = '0.304';
+our $VERSION = '0.305';
 
 =head1 NAME
 
@@ -23,15 +23,16 @@ implementation, which will die if they are not overridden.
 =cut
 
 sub new {
-    my ($class, $realm_settings) = @_;
+    my ($class, $realm_settings, $dsl) = @_;
     my $self = {
         realm_settings => $realm_settings,
+        dsl => $dsl,
     };
     return bless $self => $class;
 }
 
 sub realm_settings { shift->{realm_settings} || {} }
-
+sub realm_dsl { shift->{dsl} }
 
  
 sub match_password {
