@@ -5,7 +5,7 @@ use base 'Dancer2::Plugin::Auth::Extensible::Provider::Base';
 use Dancer2::Plugin::Database;
 use Dancer2 qw(:syntax);
 
-our $VERSION = '0.304';
+our $VERSION = '0.305';
 
 =head1 NAME 
 
@@ -182,7 +182,7 @@ sub get_user_details {
     my $settings = $self->realm_settings;
 
     # Get our database handle and find out the table and column names:
-    my $database = database($settings->{db_connection_name})
+    my $database = $self->realm_dsl->database($settings->{db_connection_name})
         or die "No database connection";
 
     my $users_table     = $settings->{users_table}     || 'users';
@@ -206,7 +206,7 @@ sub get_user_roles {
 
     my $settings = $self->realm_settings;
     # Get our database handle and find out the table and column names:
-    my $database = database($settings->{db_connection_name});
+    my $database = $self->realm_dsl->database($settings->{db_connection_name});
 
     # Get details of the user first; both to check they exist, and so we have
     # their ID to use.
